@@ -368,7 +368,7 @@ psutil_proc_num_ctx_switches(PyObject *self, PyObject *args) {
 static PyObject *
 psutil_proc_cpu_times(PyObject *self, PyObject *args) {
     long pid;
-    double user_t, sys_t;
+    double user_t, sys_t, children_user_t, children_sys_t;
     kinfo_proc kp;
     if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
@@ -378,11 +378,18 @@ psutil_proc_cpu_times(PyObject *self, PyObject *args) {
 #ifdef __FreeBSD__
     user_t = PSUTIL_TV2DOUBLE(kp.ki_rusage.ru_utime);
     sys_t = PSUTIL_TV2DOUBLE(kp.ki_rusage.ru_stime);
+    children_user_t = PSUTIL_TV2DOUBLE(kp.ki_rusage_ch.ru_utime);
+    children_sys_t = PSUTIL_TV2DOUBLE(kp.ki_rusage_ch.ru_stime);
 #elif defined(__OpenBSD__) || defined(__NetBSD__)
     user_t = PSUTIL_KPT2DOUBLE(kp.p_uutime);
     sys_t = PSUTIL_KPT2DOUBLE(kp.p_ustime);
+    // OpenBSD and NetBSD provide children user + system times summed
+    // together (no distinction).
+    children_user_t = kp.p_uctime_sec + kp.p_uctime_usec / 1000000.0;
+    children_sys_t = children_user_t;
 #endif
-    return Py_BuildValue("(dd)", user_t, sys_t);
+    return Py_BuildValue("(dddd)",
+                         user_t, sys_t, children_user_t, children_sys_t);
 }
 
 
@@ -705,16 +712,20 @@ psutil_disk_partitions(PyObject *self, PyObject *args) {
             strlcat(opts, ",union", sizeof(opts));
         if (flags & MNT_NOCOREDUMP)
             strlcat(opts, ",nocoredump", sizeof(opts));
+#if defined(MNT_RELATIME)
         if (flags & MNT_RELATIME)
             strlcat(opts, ",relatime", sizeof(opts));
+#endif
         if (flags & MNT_IGNORE)
             strlcat(opts, ",ignore", sizeof(opts));
 #if defined(MNT_DISCARD)
         if (flags & MNT_DISCARD)
             strlcat(opts, ",discard", sizeof(opts));
 #endif
+#if defined(MNT_EXTATTR)
         if (flags & MNT_EXTATTR)
             strlcat(opts, ",extattr", sizeof(opts));
+#endif
         if (flags & MNT_LOG)
             strlcat(opts, ",log", sizeof(opts));
         if (flags & MNT_SYMPERM)
@@ -812,7 +823,12 @@ psutil_net_io_counters(PyObject *self, PyObject *args) {
                                         if2m->ifm_data.ifi_ierrors,
                                         if2m->ifm_data.ifi_oerrors,
                                         if2m->ifm_data.ifi_iqdrops,
-                                        0);  // dropout not supported
+#ifdef _IFI_OQDROPS
+                                        if2m->ifm_data.ifi_oqdrops
+#else
+                                        0
+#endif
+                                        );
             if (!py_ifc_info)
                 goto error;
             if (PyDict_SetItemString(py_retdict, ifc_name, py_ifc_info))
@@ -1006,6 +1022,8 @@ PsutilMethods[] = {
      "Return a Python dict of tuples for disk I/O information"},
     {"users", psutil_users, METH_VARARGS,
      "Return currently connected users as a list of tuples"},
+    {"cpu_stats", psutil_cpu_stats, METH_VARARGS,
+     "Return CPU statistics"},
 #if defined(__FreeBSD__) || defined(__NetBSD__)
     {"net_connections", psutil_net_connections, METH_VARARGS,
      "Return system-wide open connections."},
